@@ -1,7 +1,5 @@
 package FooObject;
 use Function::Interface::Impl qw(IFoo);
-use Function::Parameters;
-use Function::Return;
 
 fun foo() :Return() { }
 
